==> static-compat-qt6-wayland-6.9.3-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6WaylandCompositor/Qt6QWaylandEglStreamClientBufferIntegrationPluginDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

set(QWaylandEglStreamClientBufferIntegrationPlugin_FOUND TRUE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_third_party_deps "Wayland\;FALSE\;1.15\;\;;Wayland\;FALSE\;1.15\;\;")
_qt_internal_find_third_party_dependencies("QWaylandEglStreamClientBufferIntegrationPlugin" __qt_QWaylandEglStreamClientBufferIntegrationPlugin_third_party_deps)
unset(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_third_party_deps)

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_target_deps "Qt6Core\;6.9.3;Qt6Gui\;6.9.3;Qt6WaylandCompositor\;6.9.3;Qt6CorePrivate\;6.9.3;Qt6GuiPrivate\;6.9.3;Qt6WaylandCompositorPrivate\;6.9.3")
set(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/..;${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("QWaylandEglStreamClientBufferIntegrationPlugin" __qt_QWaylandEglStreamClientBufferIntegrationPlugin_target_deps
                                  __qt_QWaylandEglStreamClientBufferIntegrationPlugin_find_dependency_paths)
unset(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_target_deps)
unset(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_find_dependency_paths)

if(__qt_${target}_missing_deps)
    set(QWaylandEglStreamClientBufferIntegrationPlugin_FOUND FALSE)
endif()

==> static-compat-qt6-wayland-6.10.0-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6WaylandCompositor/Qt6QWaylandEglStreamClientBufferIntegrationPluginDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

set(QWaylandEglStreamClientBufferIntegrationPlugin_FOUND TRUE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_third_party_deps "Wayland\;FALSE\;1.15\;\;;Wayland\;FALSE\;1.15\;\;")
_qt_internal_find_third_party_dependencies("QWaylandEglStreamClientBufferIntegrationPlugin" __qt_QWaylandEglStreamClientBufferIntegrationPlugin_third_party_deps)
unset(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_third_party_deps)

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_target_deps "Qt6Core\;6.10.0;Qt6Gui\;6.10.0;Qt6WaylandCompositor\;6.10.0")
set(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/..;${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("QWaylandEglStreamClientBufferIntegrationPlugin" __qt_QWaylandEglStreamClientBufferIntegrationPlugin_target_deps
                                  __qt_QWaylandEglStreamClientBufferIntegrationPlugin_find_dependency_paths)
unset(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_target_deps)
unset(__qt_QWaylandEglStreamClientBufferIntegrationPlugin_find_dependency_paths)

if(__qt_${target}_missing_deps)
    set(QWaylandEglStreamClientBufferIntegrationPlugin_FOUND FALSE)
endif()
